#[non_exhaustive]pub enum BatchStatus {
Starting,
Started,
Stopping,
Stopped,
Failed,
Completed,
Abandoned,
Unknown,
}Expand description
The framework lifecycle status of a job or step execution.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Starting
Metadata exists and user work has not started.
Started
User work is running.
Stopping
A cooperative stop is in progress.
Stopped
The attempt stopped cooperatively and may be restarted.
Failed
The attempt failed and may be restartable.
Completed
The attempt completed successfully.
Abandoned
The instance is intentionally terminal and cannot restart.
Unknown
The durable outcome is ambiguous and requires recovery.
Implementations
Sourceimpl BatchStatus
impl BatchStatus
Sourcepub const fn is_active(self) -> bool
pub const fn is_active(self) -> bool
Returns whether the attempt is actively running or stopping.
Sourcepub const fn is_finished(self) -> bool
pub const fn is_finished(self) -> bool
Returns whether the attempt has a known finished outcome.
Sourcepub const fn is_terminal(self) -> bool
pub const fn is_terminal(self) -> bool
Returns whether the logical instance is terminal and not restartable.