#[non_exhaustive]pub enum InFlightPolicy {
FinishChunk,
RollbackChunk,
}Expand description
The accepted shutdown behavior for an already-open chunk.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FinishChunk
Complete and commit the open chunk, then stop at its boundary.
RollbackChunk
Roll back the open chunk and preserve the prior checkpoint.