pub struct ChunkComponentRevisions { /* private fields */ }Expand description
Component revisions for a one-step chunk definition.
Implementations
Sourceimpl ChunkComponentRevisions
impl ChunkComponentRevisions
Sourcepub const fn new(
reader: ComponentRevision,
processor: ComponentRevision,
writer: ComponentRevision,
checkpoint: ComponentRevision,
restart: ChunkRestartContract,
) -> Self
pub const fn new( reader: ComponentRevision, processor: ComponentRevision, writer: ComponentRevision, checkpoint: ComponentRevision, restart: ChunkRestartContract, ) -> Self
Constructs the four restart-relevant chunk component revisions.
Sourcepub const fn delivery_mode(&self) -> ChunkDeliveryMode
pub const fn delivery_mode(&self) -> ChunkDeliveryMode
Returns the delivery mode declared by the restart contract.
Sourcepub const fn in_flight_policy(&self) -> InFlightPolicy
pub const fn in_flight_policy(&self) -> InFlightPolicy
Returns the shutdown policy of an already-open chunk.
Sourcepub const fn reader(&self) -> &ComponentRevision
pub const fn reader(&self) -> &ComponentRevision
Borrows the revision of the component that reads items.
Sourcepub const fn processor(&self) -> &ComponentRevision
pub const fn processor(&self) -> &ComponentRevision
Borrows the revision of the component that processes items.
Sourcepub const fn writer(&self) -> &ComponentRevision
pub const fn writer(&self) -> &ComponentRevision
Borrows the revision of the component that writes items.
Sourcepub const fn checkpoint(&self) -> &ComponentRevision
pub const fn checkpoint(&self) -> &ComponentRevision
Borrows the revision of the component that produces checkpoints.
Sourcepub const fn checkpoint_schema(&self) -> &StateSchemaId
pub const fn checkpoint_schema(&self) -> &StateSchemaId
Borrows the declared checkpoint schema.
Sourcepub const fn checkpoint_schema_version(&self) -> StateSchemaVersion
pub const fn checkpoint_schema_version(&self) -> StateSchemaVersion
Returns the declared checkpoint schema version.
Sourcepub const fn context_schema(&self) -> &StateSchemaId
pub const fn context_schema(&self) -> &StateSchemaId
Borrows the declared execution-context schema.
Sourcepub const fn context_schema_version(&self) -> StateSchemaVersion
pub const fn context_schema_version(&self) -> StateSchemaVersion
Returns the declared execution-context schema version.