pub struct StartControls { /* private fields */ }Expand description
Restart-relevant start controls for one logical step.
Implementations
Sourceimpl StartControls
impl StartControls
Sourcepub const fn new(start_limit: StartLimit, allow_start_if_complete: bool) -> Self
pub const fn new(start_limit: StartLimit, allow_start_if_complete: bool) -> Self
Constructs explicit start controls.
Sourcepub const fn start_limit(&self) -> StartLimit
pub const fn start_limit(&self) -> StartLimit
Returns the maximum number of starts for one job instance.
Sourcepub const fn allow_start_if_complete(&self) -> bool
pub const fn allow_start_if_complete(&self) -> bool
Returns whether a restart path reruns an already completed step.